# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/report/v1/report.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=github.com/metaprov/modelaapi/services/report/v1/report.proto\x12\x30github.com.metaprov.modelaapi.services.report.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1aHgithub.com/metaprov/modelaapi/pkg/apis/training/v1alpha1/generated.proto\"\xf1\x01\n\x12ListReportsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12`\n\x06labels\x18\x02 \x03(\x0b\x32P.github.com.metaprov.modelaapi.services.report.v1.ListReportsRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x85\x01\n\x13ListReportsResponse\x12U\n\x07reports\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ReportList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"g\n\x13\x43reateReportRequest\x12P\n\x06report\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Report\"\x16\n\x14\x43reateReportResponse\"\x97\x01\n\x13UpdateReportRequest\x12P\n\x06report\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Report\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x16\n\x14UpdateReportResponse\"3\n\x10GetReportRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"s\n\x11GetReportResponse\x12P\n\x06report\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Report\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"6\n\x13\x44\x65leteReportRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x16\n\x14\x44\x65leteReportResponse\"8\n\x15\x44ownloadReportRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"%\n\x16\x44ownloadReportResponse\x12\x0b\n\x03raw\x18\x01 \x01(\x0c\x32\xc8\t\n\rReportService\x12\xbb\x01\n\x0bListReports\x12\x44.github.com.metaprov.modelaapi.services.report.v1.ListReportsRequest\x1a\x45.github.com.metaprov.modelaapi.services.report.v1.ListReportsResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/reports/{namespace}\x12\xb5\x01\n\x0c\x43reateReport\x12\x45.github.com.metaprov.modelaapi.services.report.v1.CreateReportRequest\x1a\x46.github.com.metaprov.modelaapi.services.report.v1.CreateReportResponse\"\x16\x82\xd3\xe4\x93\x02\x10\"\x0b/v1/reports:\x01*\x12\xbc\x01\n\tGetReport\x12\x42.github.com.metaprov.modelaapi.services.report.v1.GetReportRequest\x1a\x43.github.com.metaprov.modelaapi.services.report.v1.GetReportResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/v1/reports/{namespace}/{name}\x12\xe8\x01\n\x0cUpdateReport\x12\x45.github.com.metaprov.modelaapi.services.report.v1.UpdateReportRequest\x1a\x46.github.com.metaprov.modelaapi.services.report.v1.UpdateReportResponse\"I\x82\xd3\xe4\x93\x02\x43\x1a>/v1/reports/{report.metadata.namespace}/{report.metadata.name}:\x01*\x12\xc5\x01\n\x0c\x44\x65leteReport\x12\x45.github.com.metaprov.modelaapi.services.report.v1.DeleteReportRequest\x1a\x46.github.com.metaprov.modelaapi.services.report.v1.DeleteReportResponse\"&\x82\xd3\xe4\x93\x02 *\x1e/v1/reports/{namespace}/{name}\x12\xce\x01\n\x08\x44ownload\x12G.github.com.metaprov.modelaapi.services.report.v1.DownloadReportRequest\x1aH.github.com.metaprov.modelaapi.services.report.v1.DownloadReportResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/v1/reports/{namespace}/{name}:downloadB2Z0github.com/metaprov/modelaapi/services/report/v1b\x06proto3')



_LISTREPORTSREQUEST = DESCRIPTOR.message_types_by_name['ListReportsRequest']
_LISTREPORTSREQUEST_LABELSENTRY = _LISTREPORTSREQUEST.nested_types_by_name['LabelsEntry']
_LISTREPORTSRESPONSE = DESCRIPTOR.message_types_by_name['ListReportsResponse']
_CREATEREPORTREQUEST = DESCRIPTOR.message_types_by_name['CreateReportRequest']
_CREATEREPORTRESPONSE = DESCRIPTOR.message_types_by_name['CreateReportResponse']
_UPDATEREPORTREQUEST = DESCRIPTOR.message_types_by_name['UpdateReportRequest']
_UPDATEREPORTRESPONSE = DESCRIPTOR.message_types_by_name['UpdateReportResponse']
_GETREPORTREQUEST = DESCRIPTOR.message_types_by_name['GetReportRequest']
_GETREPORTRESPONSE = DESCRIPTOR.message_types_by_name['GetReportResponse']
_DELETEREPORTREQUEST = DESCRIPTOR.message_types_by_name['DeleteReportRequest']
_DELETEREPORTRESPONSE = DESCRIPTOR.message_types_by_name['DeleteReportResponse']
_DOWNLOADREPORTREQUEST = DESCRIPTOR.message_types_by_name['DownloadReportRequest']
_DOWNLOADREPORTRESPONSE = DESCRIPTOR.message_types_by_name['DownloadReportResponse']
ListReportsRequest = _reflection.GeneratedProtocolMessageType('ListReportsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTREPORTSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.report.v1.report_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.report.v1.ListReportsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTREPORTSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.report.v1.report_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.report.v1.ListReportsRequest)
  })
_sym_db.RegisterMessage(ListReportsRequest)
_sym_db.RegisterMessage(ListReportsRequest.LabelsEntry)

ListReportsResponse = _reflection.GeneratedProtocolMessageType('ListReportsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTREPORTSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.report.v1.report_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.report.v1.ListReportsResponse)
  })
_sym_db.RegisterMessage(ListReportsResponse)

CreateReportRequest = _reflection.GeneratedProtocolMessageType('CreateReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.report.v1.report_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.report.v1.CreateReportRequest)
  })
_sym_db.RegisterMessage(CreateReportRequest)

CreateReportResponse = _reflection.GeneratedProtocolMessageType('CreateReportResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEREPORTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.report.v1.report_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.report.v1.CreateReportResponse)
  })
_sym_db.RegisterMessage(CreateReportResponse)

UpdateReportRequest = _reflection.GeneratedProtocolMessageType('UpdateReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.report.v1.report_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.report.v1.UpdateReportRequest)
  })
_sym_db.RegisterMessage(UpdateReportRequest)

UpdateReportResponse = _reflection.GeneratedProtocolMessageType('UpdateReportResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEREPORTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.report.v1.report_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.report.v1.UpdateReportResponse)
  })
_sym_db.RegisterMessage(UpdateReportResponse)

GetReportRequest = _reflection.GeneratedProtocolMessageType('GetReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.report.v1.report_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.report.v1.GetReportRequest)
  })
_sym_db.RegisterMessage(GetReportRequest)

GetReportResponse = _reflection.GeneratedProtocolMessageType('GetReportResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETREPORTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.report.v1.report_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.report.v1.GetReportResponse)
  })
_sym_db.RegisterMessage(GetReportResponse)

DeleteReportRequest = _reflection.GeneratedProtocolMessageType('DeleteReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.report.v1.report_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.report.v1.DeleteReportRequest)
  })
_sym_db.RegisterMessage(DeleteReportRequest)

DeleteReportResponse = _reflection.GeneratedProtocolMessageType('DeleteReportResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEREPORTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.report.v1.report_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.report.v1.DeleteReportResponse)
  })
_sym_db.RegisterMessage(DeleteReportResponse)

DownloadReportRequest = _reflection.GeneratedProtocolMessageType('DownloadReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.report.v1.report_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.report.v1.DownloadReportRequest)
  })
_sym_db.RegisterMessage(DownloadReportRequest)

DownloadReportResponse = _reflection.GeneratedProtocolMessageType('DownloadReportResponse', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADREPORTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.report.v1.report_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.report.v1.DownloadReportResponse)
  })
_sym_db.RegisterMessage(DownloadReportResponse)

_REPORTSERVICE = DESCRIPTOR.services_by_name['ReportService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z0github.com/metaprov/modelaapi/services/report/v1'
  _LISTREPORTSREQUEST_LABELSENTRY._options = None
  _LISTREPORTSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _REPORTSERVICE.methods_by_name['ListReports']._options = None
  _REPORTSERVICE.methods_by_name['ListReports']._serialized_options = b'\202\323\344\223\002\031\022\027/v1/reports/{namespace}'
  _REPORTSERVICE.methods_by_name['CreateReport']._options = None
  _REPORTSERVICE.methods_by_name['CreateReport']._serialized_options = b'\202\323\344\223\002\020\"\013/v1/reports:\001*'
  _REPORTSERVICE.methods_by_name['GetReport']._options = None
  _REPORTSERVICE.methods_by_name['GetReport']._serialized_options = b'\202\323\344\223\002 \022\036/v1/reports/{namespace}/{name}'
  _REPORTSERVICE.methods_by_name['UpdateReport']._options = None
  _REPORTSERVICE.methods_by_name['UpdateReport']._serialized_options = b'\202\323\344\223\002C\032>/v1/reports/{report.metadata.namespace}/{report.metadata.name}:\001*'
  _REPORTSERVICE.methods_by_name['DeleteReport']._options = None
  _REPORTSERVICE.methods_by_name['DeleteReport']._serialized_options = b'\202\323\344\223\002 *\036/v1/reports/{namespace}/{name}'
  _REPORTSERVICE.methods_by_name['Download']._options = None
  _REPORTSERVICE.methods_by_name['Download']._serialized_options = b'\202\323\344\223\002)\022\'/v1/reports/{namespace}/{name}:download'
  _LISTREPORTSREQUEST._serialized_start=254
  _LISTREPORTSREQUEST._serialized_end=495
  _LISTREPORTSREQUEST_LABELSENTRY._serialized_start=450
  _LISTREPORTSREQUEST_LABELSENTRY._serialized_end=495
  _LISTREPORTSRESPONSE._serialized_start=498
  _LISTREPORTSRESPONSE._serialized_end=631
  _CREATEREPORTREQUEST._serialized_start=633
  _CREATEREPORTREQUEST._serialized_end=736
  _CREATEREPORTRESPONSE._serialized_start=738
  _CREATEREPORTRESPONSE._serialized_end=760
  _UPDATEREPORTREQUEST._serialized_start=763
  _UPDATEREPORTREQUEST._serialized_end=914
  _UPDATEREPORTRESPONSE._serialized_start=916
  _UPDATEREPORTRESPONSE._serialized_end=938
  _GETREPORTREQUEST._serialized_start=940
  _GETREPORTREQUEST._serialized_end=991
  _GETREPORTRESPONSE._serialized_start=993
  _GETREPORTRESPONSE._serialized_end=1108
  _DELETEREPORTREQUEST._serialized_start=1110
  _DELETEREPORTREQUEST._serialized_end=1164
  _DELETEREPORTRESPONSE._serialized_start=1166
  _DELETEREPORTRESPONSE._serialized_end=1188
  _DOWNLOADREPORTREQUEST._serialized_start=1190
  _DOWNLOADREPORTREQUEST._serialized_end=1246
  _DOWNLOADREPORTRESPONSE._serialized_start=1248
  _DOWNLOADREPORTRESPONSE._serialized_end=1285
  _REPORTSERVICE._serialized_start=1288
  _REPORTSERVICE._serialized_end=2512
# @@protoc_insertion_point(module_scope)
