# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: k8s.io/api/apps/v1/generated.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from k8s.io.api.core.v1 import generated_pb2 as k8s_dot_io_dot_api_dot_core_dot_v1_dot_generated__pb2
from k8s.io.apimachinery.pkg.apis.meta.v1 import generated_pb2 as k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2
from k8s.io.apimachinery.pkg.runtime import generated_pb2 as k8s_dot_io_dot_apimachinery_dot_pkg_dot_runtime_dot_generated__pb2
from k8s.io.apimachinery.pkg.runtime.schema import generated_pb2 as k8s_dot_io_dot_apimachinery_dot_pkg_dot_runtime_dot_schema_dot_generated__pb2
from k8s.io.apimachinery.pkg.util.intstr import generated_pb2 as k8s_dot_io_dot_apimachinery_dot_pkg_dot_util_dot_intstr_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"k8s.io/api/apps/v1/generated.proto\x12\x12k8s.io.api.apps.v1\x1a\"k8s.io/api/core/v1/generated.proto\x1a\x34k8s.io/apimachinery/pkg/apis/meta/v1/generated.proto\x1a/k8s.io/apimachinery/pkg/runtime/generated.proto\x1a\x36k8s.io/apimachinery/pkg/runtime/schema/generated.proto\x1a\x33k8s.io/apimachinery/pkg/util/intstr/generated.proto\"\xa7\x01\n\x12\x43ontrollerRevision\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12;\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32-.k8s.io.apimachinery.pkg.runtime.RawExtension\x12\x10\n\x08revision\x18\x03 \x01(\x03\"\x91\x01\n\x16\x43ontrollerRevisionList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x35\n\x05items\x18\x02 \x03(\x0b\x32&.k8s.io.api.apps.v1.ControllerRevision\"\xb5\x01\n\tDaemonSet\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12/\n\x04spec\x18\x02 \x01(\x0b\x32!.k8s.io.api.apps.v1.DaemonSetSpec\x12\x33\n\x06status\x18\x03 \x01(\x0b\x32#.k8s.io.api.apps.v1.DaemonSetStatus\"\x9b\x01\n\x12\x44\x61\x65monSetCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x03 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\"\x7f\n\rDaemonSetList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12,\n\x05items\x18\x02 \x03(\x0b\x32\x1d.k8s.io.api.apps.v1.DaemonSet\"\x89\x02\n\rDaemonSetSpec\x12\x45\n\x08selector\x18\x01 \x01(\x0b\x32\x33.k8s.io.apimachinery.pkg.apis.meta.v1.LabelSelector\x12\x35\n\x08template\x18\x02 \x01(\x0b\x32#.k8s.io.api.core.v1.PodTemplateSpec\x12\x43\n\x0eupdateStrategy\x18\x03 \x01(\x0b\x32+.k8s.io.api.apps.v1.DaemonSetUpdateStrategy\x12\x17\n\x0fminReadySeconds\x18\x04 \x01(\x05\x12\x1c\n\x14revisionHistoryLimit\x18\x06 \x01(\x05\"\xc6\x02\n\x0f\x44\x61\x65monSetStatus\x12\x1e\n\x16\x63urrentNumberScheduled\x18\x01 \x01(\x05\x12\x1a\n\x12numberMisscheduled\x18\x02 \x01(\x05\x12\x1e\n\x16\x64\x65siredNumberScheduled\x18\x03 \x01(\x05\x12\x13\n\x0bnumberReady\x18\x04 \x01(\x05\x12\x1a\n\x12observedGeneration\x18\x05 \x01(\x03\x12\x1e\n\x16updatedNumberScheduled\x18\x06 \x01(\x05\x12\x17\n\x0fnumberAvailable\x18\x07 \x01(\x05\x12\x19\n\x11numberUnavailable\x18\x08 \x01(\x05\x12\x16\n\x0e\x63ollisionCount\x18\t \x01(\x05\x12:\n\nconditions\x18\n \x03(\x0b\x32&.k8s.io.api.apps.v1.DaemonSetCondition\"j\n\x17\x44\x61\x65monSetUpdateStrategy\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x41\n\rrollingUpdate\x18\x02 \x01(\x0b\x32*.k8s.io.api.apps.v1.RollingUpdateDaemonSet\"\xb8\x01\n\nDeployment\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x30\n\x04spec\x18\x02 \x01(\x0b\x32\".k8s.io.api.apps.v1.DeploymentSpec\x12\x34\n\x06status\x18\x03 \x01(\x0b\x32$.k8s.io.api.apps.v1.DeploymentStatus\"\xe0\x01\n\x13\x44\x65ploymentCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x42\n\x0elastUpdateTime\x18\x06 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x46\n\x12lastTransitionTime\x18\x07 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\"\x81\x01\n\x0e\x44\x65ploymentList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12-\n\x05items\x18\x02 \x03(\x0b\x32\x1e.k8s.io.api.apps.v1.Deployment\"\xc2\x02\n\x0e\x44\x65ploymentSpec\x12\x10\n\x08replicas\x18\x01 \x01(\x05\x12\x45\n\x08selector\x18\x02 \x01(\x0b\x32\x33.k8s.io.apimachinery.pkg.apis.meta.v1.LabelSelector\x12\x35\n\x08template\x18\x03 \x01(\x0b\x32#.k8s.io.api.core.v1.PodTemplateSpec\x12\x38\n\x08strategy\x18\x04 \x01(\x0b\x32&.k8s.io.api.apps.v1.DeploymentStrategy\x12\x17\n\x0fminReadySeconds\x18\x05 \x01(\x05\x12\x1c\n\x14revisionHistoryLimit\x18\x06 \x01(\x05\x12\x0e\n\x06paused\x18\x07 \x01(\x08\x12\x1f\n\x17progressDeadlineSeconds\x18\t \x01(\x05\"\xfd\x01\n\x10\x44\x65ploymentStatus\x12\x1a\n\x12observedGeneration\x18\x01 \x01(\x03\x12\x10\n\x08replicas\x18\x02 \x01(\x05\x12\x17\n\x0fupdatedReplicas\x18\x03 \x01(\x05\x12\x15\n\rreadyReplicas\x18\x07 \x01(\x05\x12\x19\n\x11\x61vailableReplicas\x18\x04 \x01(\x05\x12\x1b\n\x13unavailableReplicas\x18\x05 \x01(\x05\x12;\n\nconditions\x18\x06 \x03(\x0b\x32\'.k8s.io.api.apps.v1.DeploymentCondition\x12\x16\n\x0e\x63ollisionCount\x18\x08 \x01(\x05\"f\n\x12\x44\x65ploymentStrategy\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x42\n\rrollingUpdate\x18\x02 \x01(\x0b\x32+.k8s.io.api.apps.v1.RollingUpdateDeployment\"\xb8\x01\n\nReplicaSet\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x30\n\x04spec\x18\x02 \x01(\x0b\x32\".k8s.io.api.apps.v1.ReplicaSetSpec\x12\x34\n\x06status\x18\x03 \x01(\x0b\x32$.k8s.io.api.apps.v1.ReplicaSetStatus\"\x9c\x01\n\x13ReplicaSetCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x03 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\"\x81\x01\n\x0eReplicaSetList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12-\n\x05items\x18\x02 \x03(\x0b\x32\x1e.k8s.io.api.apps.v1.ReplicaSet\"\xb9\x01\n\x0eReplicaSetSpec\x12\x10\n\x08replicas\x18\x01 \x01(\x05\x12\x17\n\x0fminReadySeconds\x18\x04 \x01(\x05\x12\x45\n\x08selector\x18\x02 \x01(\x0b\x32\x33.k8s.io.apimachinery.pkg.apis.meta.v1.LabelSelector\x12\x35\n\x08template\x18\x03 \x01(\x0b\x32#.k8s.io.api.core.v1.PodTemplateSpec\"\xcd\x01\n\x10ReplicaSetStatus\x12\x10\n\x08replicas\x18\x01 \x01(\x05\x12\x1c\n\x14\x66ullyLabeledReplicas\x18\x02 \x01(\x05\x12\x15\n\rreadyReplicas\x18\x04 \x01(\x05\x12\x19\n\x11\x61vailableReplicas\x18\x05 \x01(\x05\x12\x1a\n\x12observedGeneration\x18\x03 \x01(\x03\x12;\n\nconditions\x18\x06 \x03(\x0b\x32\'.k8s.io.api.apps.v1.ReplicaSetCondition\"\xa6\x01\n\x16RollingUpdateDaemonSet\x12H\n\x0emaxUnavailable\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.util.intstr.IntOrString\x12\x42\n\x08maxSurge\x18\x02 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.util.intstr.IntOrString\"\xa7\x01\n\x17RollingUpdateDeployment\x12H\n\x0emaxUnavailable\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.util.intstr.IntOrString\x12\x42\n\x08maxSurge\x18\x02 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.util.intstr.IntOrString\"\x7f\n RollingUpdateStatefulSetStrategy\x12\x11\n\tpartition\x18\x01 \x01(\x05\x12H\n\x0emaxUnavailable\x18\x02 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.util.intstr.IntOrString\"\xbb\x01\n\x0bStatefulSet\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x31\n\x04spec\x18\x02 \x01(\x0b\x32#.k8s.io.api.apps.v1.StatefulSetSpec\x12\x35\n\x06status\x18\x03 \x01(\x0b\x32%.k8s.io.api.apps.v1.StatefulSetStatus\"\x9d\x01\n\x14StatefulSetCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x03 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\"\x83\x01\n\x0fStatefulSetList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12.\n\x05items\x18\x02 \x03(\x0b\x32\x1f.k8s.io.api.apps.v1.StatefulSet\"Z\n/StatefulSetPersistentVolumeClaimRetentionPolicy\x12\x13\n\x0bwhenDeleted\x18\x01 \x01(\t\x12\x12\n\nwhenScaled\x18\x02 \x01(\t\"\x8d\x04\n\x0fStatefulSetSpec\x12\x10\n\x08replicas\x18\x01 \x01(\x05\x12\x45\n\x08selector\x18\x02 \x01(\x0b\x32\x33.k8s.io.apimachinery.pkg.apis.meta.v1.LabelSelector\x12\x35\n\x08template\x18\x03 \x01(\x0b\x32#.k8s.io.api.core.v1.PodTemplateSpec\x12G\n\x14volumeClaimTemplates\x18\x04 \x03(\x0b\x32).k8s.io.api.core.v1.PersistentVolumeClaim\x12\x13\n\x0bserviceName\x18\x05 \x01(\t\x12\x1b\n\x13podManagementPolicy\x18\x06 \x01(\t\x12\x45\n\x0eupdateStrategy\x18\x07 \x01(\x0b\x32-.k8s.io.api.apps.v1.StatefulSetUpdateStrategy\x12\x1c\n\x14revisionHistoryLimit\x18\x08 \x01(\x05\x12\x17\n\x0fminReadySeconds\x18\t \x01(\x05\x12q\n$persistentVolumeClaimRetentionPolicy\x18\n \x01(\x0b\x32\x43.k8s.io.api.apps.v1.StatefulSetPersistentVolumeClaimRetentionPolicy\"\xac\x02\n\x11StatefulSetStatus\x12\x1a\n\x12observedGeneration\x18\x01 \x01(\x03\x12\x10\n\x08replicas\x18\x02 \x01(\x05\x12\x15\n\rreadyReplicas\x18\x03 \x01(\x05\x12\x17\n\x0f\x63urrentReplicas\x18\x04 \x01(\x05\x12\x17\n\x0fupdatedReplicas\x18\x05 \x01(\x05\x12\x17\n\x0f\x63urrentRevision\x18\x06 \x01(\t\x12\x16\n\x0eupdateRevision\x18\x07 \x01(\t\x12\x16\n\x0e\x63ollisionCount\x18\t \x01(\x05\x12<\n\nconditions\x18\n \x03(\x0b\x32(.k8s.io.api.apps.v1.StatefulSetCondition\x12\x19\n\x11\x61vailableReplicas\x18\x0b \x01(\x05\"v\n\x19StatefulSetUpdateStrategy\x12\x0c\n\x04type\x18\x01 \x01(\t\x12K\n\rrollingUpdate\x18\x02 \x01(\x0b\x32\x34.k8s.io.api.apps.v1.RollingUpdateStatefulSetStrategyB\x14Z\x12k8s.io/api/apps/v1')



_CONTROLLERREVISION = DESCRIPTOR.message_types_by_name['ControllerRevision']
_CONTROLLERREVISIONLIST = DESCRIPTOR.message_types_by_name['ControllerRevisionList']
_DAEMONSET = DESCRIPTOR.message_types_by_name['DaemonSet']
_DAEMONSETCONDITION = DESCRIPTOR.message_types_by_name['DaemonSetCondition']
_DAEMONSETLIST = DESCRIPTOR.message_types_by_name['DaemonSetList']
_DAEMONSETSPEC = DESCRIPTOR.message_types_by_name['DaemonSetSpec']
_DAEMONSETSTATUS = DESCRIPTOR.message_types_by_name['DaemonSetStatus']
_DAEMONSETUPDATESTRATEGY = DESCRIPTOR.message_types_by_name['DaemonSetUpdateStrategy']
_DEPLOYMENT = DESCRIPTOR.message_types_by_name['Deployment']
_DEPLOYMENTCONDITION = DESCRIPTOR.message_types_by_name['DeploymentCondition']
_DEPLOYMENTLIST = DESCRIPTOR.message_types_by_name['DeploymentList']
_DEPLOYMENTSPEC = DESCRIPTOR.message_types_by_name['DeploymentSpec']
_DEPLOYMENTSTATUS = DESCRIPTOR.message_types_by_name['DeploymentStatus']
_DEPLOYMENTSTRATEGY = DESCRIPTOR.message_types_by_name['DeploymentStrategy']
_REPLICASET = DESCRIPTOR.message_types_by_name['ReplicaSet']
_REPLICASETCONDITION = DESCRIPTOR.message_types_by_name['ReplicaSetCondition']
_REPLICASETLIST = DESCRIPTOR.message_types_by_name['ReplicaSetList']
_REPLICASETSPEC = DESCRIPTOR.message_types_by_name['ReplicaSetSpec']
_REPLICASETSTATUS = DESCRIPTOR.message_types_by_name['ReplicaSetStatus']
_ROLLINGUPDATEDAEMONSET = DESCRIPTOR.message_types_by_name['RollingUpdateDaemonSet']
_ROLLINGUPDATEDEPLOYMENT = DESCRIPTOR.message_types_by_name['RollingUpdateDeployment']
_ROLLINGUPDATESTATEFULSETSTRATEGY = DESCRIPTOR.message_types_by_name['RollingUpdateStatefulSetStrategy']
_STATEFULSET = DESCRIPTOR.message_types_by_name['StatefulSet']
_STATEFULSETCONDITION = DESCRIPTOR.message_types_by_name['StatefulSetCondition']
_STATEFULSETLIST = DESCRIPTOR.message_types_by_name['StatefulSetList']
_STATEFULSETPERSISTENTVOLUMECLAIMRETENTIONPOLICY = DESCRIPTOR.message_types_by_name['StatefulSetPersistentVolumeClaimRetentionPolicy']
_STATEFULSETSPEC = DESCRIPTOR.message_types_by_name['StatefulSetSpec']
_STATEFULSETSTATUS = DESCRIPTOR.message_types_by_name['StatefulSetStatus']
_STATEFULSETUPDATESTRATEGY = DESCRIPTOR.message_types_by_name['StatefulSetUpdateStrategy']
ControllerRevision = _reflection.GeneratedProtocolMessageType('ControllerRevision', (_message.Message,), {
  'DESCRIPTOR' : _CONTROLLERREVISION,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.ControllerRevision)
  })
_sym_db.RegisterMessage(ControllerRevision)

ControllerRevisionList = _reflection.GeneratedProtocolMessageType('ControllerRevisionList', (_message.Message,), {
  'DESCRIPTOR' : _CONTROLLERREVISIONLIST,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.ControllerRevisionList)
  })
_sym_db.RegisterMessage(ControllerRevisionList)

DaemonSet = _reflection.GeneratedProtocolMessageType('DaemonSet', (_message.Message,), {
  'DESCRIPTOR' : _DAEMONSET,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.DaemonSet)
  })
_sym_db.RegisterMessage(DaemonSet)

DaemonSetCondition = _reflection.GeneratedProtocolMessageType('DaemonSetCondition', (_message.Message,), {
  'DESCRIPTOR' : _DAEMONSETCONDITION,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.DaemonSetCondition)
  })
_sym_db.RegisterMessage(DaemonSetCondition)

DaemonSetList = _reflection.GeneratedProtocolMessageType('DaemonSetList', (_message.Message,), {
  'DESCRIPTOR' : _DAEMONSETLIST,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.DaemonSetList)
  })
_sym_db.RegisterMessage(DaemonSetList)

DaemonSetSpec = _reflection.GeneratedProtocolMessageType('DaemonSetSpec', (_message.Message,), {
  'DESCRIPTOR' : _DAEMONSETSPEC,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.DaemonSetSpec)
  })
_sym_db.RegisterMessage(DaemonSetSpec)

DaemonSetStatus = _reflection.GeneratedProtocolMessageType('DaemonSetStatus', (_message.Message,), {
  'DESCRIPTOR' : _DAEMONSETSTATUS,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.DaemonSetStatus)
  })
_sym_db.RegisterMessage(DaemonSetStatus)

DaemonSetUpdateStrategy = _reflection.GeneratedProtocolMessageType('DaemonSetUpdateStrategy', (_message.Message,), {
  'DESCRIPTOR' : _DAEMONSETUPDATESTRATEGY,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.DaemonSetUpdateStrategy)
  })
_sym_db.RegisterMessage(DaemonSetUpdateStrategy)

Deployment = _reflection.GeneratedProtocolMessageType('Deployment', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYMENT,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.Deployment)
  })
_sym_db.RegisterMessage(Deployment)

DeploymentCondition = _reflection.GeneratedProtocolMessageType('DeploymentCondition', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYMENTCONDITION,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.DeploymentCondition)
  })
_sym_db.RegisterMessage(DeploymentCondition)

DeploymentList = _reflection.GeneratedProtocolMessageType('DeploymentList', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYMENTLIST,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.DeploymentList)
  })
_sym_db.RegisterMessage(DeploymentList)

DeploymentSpec = _reflection.GeneratedProtocolMessageType('DeploymentSpec', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYMENTSPEC,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.DeploymentSpec)
  })
_sym_db.RegisterMessage(DeploymentSpec)

DeploymentStatus = _reflection.GeneratedProtocolMessageType('DeploymentStatus', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYMENTSTATUS,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.DeploymentStatus)
  })
_sym_db.RegisterMessage(DeploymentStatus)

DeploymentStrategy = _reflection.GeneratedProtocolMessageType('DeploymentStrategy', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYMENTSTRATEGY,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.DeploymentStrategy)
  })
_sym_db.RegisterMessage(DeploymentStrategy)

ReplicaSet = _reflection.GeneratedProtocolMessageType('ReplicaSet', (_message.Message,), {
  'DESCRIPTOR' : _REPLICASET,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.ReplicaSet)
  })
_sym_db.RegisterMessage(ReplicaSet)

ReplicaSetCondition = _reflection.GeneratedProtocolMessageType('ReplicaSetCondition', (_message.Message,), {
  'DESCRIPTOR' : _REPLICASETCONDITION,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.ReplicaSetCondition)
  })
_sym_db.RegisterMessage(ReplicaSetCondition)

ReplicaSetList = _reflection.GeneratedProtocolMessageType('ReplicaSetList', (_message.Message,), {
  'DESCRIPTOR' : _REPLICASETLIST,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.ReplicaSetList)
  })
_sym_db.RegisterMessage(ReplicaSetList)

ReplicaSetSpec = _reflection.GeneratedProtocolMessageType('ReplicaSetSpec', (_message.Message,), {
  'DESCRIPTOR' : _REPLICASETSPEC,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.ReplicaSetSpec)
  })
_sym_db.RegisterMessage(ReplicaSetSpec)

ReplicaSetStatus = _reflection.GeneratedProtocolMessageType('ReplicaSetStatus', (_message.Message,), {
  'DESCRIPTOR' : _REPLICASETSTATUS,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.ReplicaSetStatus)
  })
_sym_db.RegisterMessage(ReplicaSetStatus)

RollingUpdateDaemonSet = _reflection.GeneratedProtocolMessageType('RollingUpdateDaemonSet', (_message.Message,), {
  'DESCRIPTOR' : _ROLLINGUPDATEDAEMONSET,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.RollingUpdateDaemonSet)
  })
_sym_db.RegisterMessage(RollingUpdateDaemonSet)

RollingUpdateDeployment = _reflection.GeneratedProtocolMessageType('RollingUpdateDeployment', (_message.Message,), {
  'DESCRIPTOR' : _ROLLINGUPDATEDEPLOYMENT,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.RollingUpdateDeployment)
  })
_sym_db.RegisterMessage(RollingUpdateDeployment)

RollingUpdateStatefulSetStrategy = _reflection.GeneratedProtocolMessageType('RollingUpdateStatefulSetStrategy', (_message.Message,), {
  'DESCRIPTOR' : _ROLLINGUPDATESTATEFULSETSTRATEGY,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.RollingUpdateStatefulSetStrategy)
  })
_sym_db.RegisterMessage(RollingUpdateStatefulSetStrategy)

StatefulSet = _reflection.GeneratedProtocolMessageType('StatefulSet', (_message.Message,), {
  'DESCRIPTOR' : _STATEFULSET,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.StatefulSet)
  })
_sym_db.RegisterMessage(StatefulSet)

StatefulSetCondition = _reflection.GeneratedProtocolMessageType('StatefulSetCondition', (_message.Message,), {
  'DESCRIPTOR' : _STATEFULSETCONDITION,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.StatefulSetCondition)
  })
_sym_db.RegisterMessage(StatefulSetCondition)

StatefulSetList = _reflection.GeneratedProtocolMessageType('StatefulSetList', (_message.Message,), {
  'DESCRIPTOR' : _STATEFULSETLIST,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.StatefulSetList)
  })
_sym_db.RegisterMessage(StatefulSetList)

StatefulSetPersistentVolumeClaimRetentionPolicy = _reflection.GeneratedProtocolMessageType('StatefulSetPersistentVolumeClaimRetentionPolicy', (_message.Message,), {
  'DESCRIPTOR' : _STATEFULSETPERSISTENTVOLUMECLAIMRETENTIONPOLICY,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.StatefulSetPersistentVolumeClaimRetentionPolicy)
  })
_sym_db.RegisterMessage(StatefulSetPersistentVolumeClaimRetentionPolicy)

StatefulSetSpec = _reflection.GeneratedProtocolMessageType('StatefulSetSpec', (_message.Message,), {
  'DESCRIPTOR' : _STATEFULSETSPEC,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.StatefulSetSpec)
  })
_sym_db.RegisterMessage(StatefulSetSpec)

StatefulSetStatus = _reflection.GeneratedProtocolMessageType('StatefulSetStatus', (_message.Message,), {
  'DESCRIPTOR' : _STATEFULSETSTATUS,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.StatefulSetStatus)
  })
_sym_db.RegisterMessage(StatefulSetStatus)

StatefulSetUpdateStrategy = _reflection.GeneratedProtocolMessageType('StatefulSetUpdateStrategy', (_message.Message,), {
  'DESCRIPTOR' : _STATEFULSETUPDATESTRATEGY,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.StatefulSetUpdateStrategy)
  })
_sym_db.RegisterMessage(StatefulSetUpdateStrategy)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\022k8s.io/api/apps/v1'
  _CONTROLLERREVISION._serialized_start=307
  _CONTROLLERREVISION._serialized_end=474
  _CONTROLLERREVISIONLIST._serialized_start=477
  _CONTROLLERREVISIONLIST._serialized_end=622
  _DAEMONSET._serialized_start=625
  _DAEMONSET._serialized_end=806
  _DAEMONSETCONDITION._serialized_start=809
  _DAEMONSETCONDITION._serialized_end=964
  _DAEMONSETLIST._serialized_start=966
  _DAEMONSETLIST._serialized_end=1093
  _DAEMONSETSPEC._serialized_start=1096
  _DAEMONSETSPEC._serialized_end=1361
  _DAEMONSETSTATUS._serialized_start=1364
  _DAEMONSETSTATUS._serialized_end=1690
  _DAEMONSETUPDATESTRATEGY._serialized_start=1692
  _DAEMONSETUPDATESTRATEGY._serialized_end=1798
  _DEPLOYMENT._serialized_start=1801
  _DEPLOYMENT._serialized_end=1985
  _DEPLOYMENTCONDITION._serialized_start=1988
  _DEPLOYMENTCONDITION._serialized_end=2212
  _DEPLOYMENTLIST._serialized_start=2215
  _DEPLOYMENTLIST._serialized_end=2344
  _DEPLOYMENTSPEC._serialized_start=2347
  _DEPLOYMENTSPEC._serialized_end=2669
  _DEPLOYMENTSTATUS._serialized_start=2672
  _DEPLOYMENTSTATUS._serialized_end=2925
  _DEPLOYMENTSTRATEGY._serialized_start=2927
  _DEPLOYMENTSTRATEGY._serialized_end=3029
  _REPLICASET._serialized_start=3032
  _REPLICASET._serialized_end=3216
  _REPLICASETCONDITION._serialized_start=3219
  _REPLICASETCONDITION._serialized_end=3375
  _REPLICASETLIST._serialized_start=3378
  _REPLICASETLIST._serialized_end=3507
  _REPLICASETSPEC._serialized_start=3510
  _REPLICASETSPEC._serialized_end=3695
  _REPLICASETSTATUS._serialized_start=3698
  _REPLICASETSTATUS._serialized_end=3903
  _ROLLINGUPDATEDAEMONSET._serialized_start=3906
  _ROLLINGUPDATEDAEMONSET._serialized_end=4072
  _ROLLINGUPDATEDEPLOYMENT._serialized_start=4075
  _ROLLINGUPDATEDEPLOYMENT._serialized_end=4242
  _ROLLINGUPDATESTATEFULSETSTRATEGY._serialized_start=4244
  _ROLLINGUPDATESTATEFULSETSTRATEGY._serialized_end=4371
  _STATEFULSET._serialized_start=4374
  _STATEFULSET._serialized_end=4561
  _STATEFULSETCONDITION._serialized_start=4564
  _STATEFULSETCONDITION._serialized_end=4721
  _STATEFULSETLIST._serialized_start=4724
  _STATEFULSETLIST._serialized_end=4855
  _STATEFULSETPERSISTENTVOLUMECLAIMRETENTIONPOLICY._serialized_start=4857
  _STATEFULSETPERSISTENTVOLUMECLAIMRETENTIONPOLICY._serialized_end=4947
  _STATEFULSETSPEC._serialized_start=4950
  _STATEFULSETSPEC._serialized_end=5475
  _STATEFULSETSTATUS._serialized_start=5478
  _STATEFULSETSTATUS._serialized_end=5778
  _STATEFULSETUPDATESTRATEGY._serialized_start=5780
  _STATEFULSETUPDATESTRATEGY._serialized_end=5898
# @@protoc_insertion_point(module_scope)
