# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/labelingpipeline/v1/labelingpipeline.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nQgithub.com/metaprov/modelaapi/services/labelingpipeline/v1/labelingpipeline.proto\x12:github.com.metaprov.modelaapi.services.labelingpipeline.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\x8d\x02\n\x1bListLabelingPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12s\n\x06labels\x18\x02 \x03(\x0b\x32\x63.github.com.metaprov.modelaapi.services.labelingpipeline.v1.ListLabelingPipelineRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9e\x01\n\x1cListLabelingPipelineResponse\x12\x65\n\x11labelingpipelines\x18\x01 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipelineList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x81\x01\n\x1d\x43reateLabelingPipelineRequest\x12`\n\x10labelingpipeline\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipeline\" \n\x1e\x43reateLabelingPipelineResponse\"\xb1\x01\n\x1dUpdateLabelingPipelineRequest\x12`\n\x10labelingpipeline\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipeline\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\" \n\x1eUpdateLabelingPipelineResponse\"=\n\x1aGetLabelingPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x8d\x01\n\x1bGetLabelingPipelineResponse\x12`\n\x10labelingpipeline\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipeline\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"@\n\x1d\x44\x65leteLabelingPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\" \n\x1e\x44\x65leteLabelingPipelineResponse\"\x1f\n\x1dPauseLabelingPipelineResponse\"?\n\x1cPauseLabelingPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\" \n\x1eResumeLabelingPipelineResponse\"@\n\x1dResumeLabelingPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t2\xc5\x0e\n\x17LabelingPipelineService\x12\xf2\x01\n\x15ListLabelingPipelines\x12W.github.com.metaprov.modelaapi.services.labelingpipeline.v1.ListLabelingPipelineRequest\x1aX.github.com.metaprov.modelaapi.services.labelingpipeline.v1.ListLabelingPipelineResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/v1/labelpipelines/{namespace}\x12\xee\x01\n\x16\x43reateLabelingPipeline\x12Y.github.com.metaprov.modelaapi.services.labelingpipeline.v1.CreateLabelingPipelineRequest\x1aZ.github.com.metaprov.modelaapi.services.labelingpipeline.v1.CreateLabelingPipelineResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/v1/labelpipelines:\x01*\x12\xf5\x01\n\x13GetLabelingPipeline\x12V.github.com.metaprov.modelaapi.services.labelingpipeline.v1.GetLabelingPipelineRequest\x1aW.github.com.metaprov.modelaapi.services.labelingpipeline.v1.GetLabelingPipelineResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/v1/labelpipelines/{namespace}/{name}\x12\xb5\x02\n\x16UpdateLabelingPipeline\x12Y.github.com.metaprov.modelaapi.services.labelingpipeline.v1.UpdateLabelingPipelineRequest\x1aZ.github.com.metaprov.modelaapi.services.labelingpipeline.v1.UpdateLabelingPipelineResponse\"d\x82\xd3\xe4\x93\x02^\x1aY/v1/labelpipelines/{labelingpipeline.metadata.namespace}/{labelingpipeline.metadata.name}:\x01*\x12\x81\x02\n\x16\x44\x65leteLabelingPipeline\x12Y.github.com.metaprov.modelaapi.services.labelingpipeline.v1.DeleteLabelingPipelineRequest\x1aZ.github.com.metaprov.modelaapi.services.labelingpipeline.v1.DeleteLabelingPipelineResponse\"0\x82\xd3\xe4\x93\x02**(/v1/labelingpipelines/{namespace}/{name}\x12\x84\x02\n\x15PauseLabelingPipeline\x12X.github.com.metaprov.modelaapi.services.labelingpipeline.v1.PauseLabelingPipelineRequest\x1aY.github.com.metaprov.modelaapi.services.labelingpipeline.v1.PauseLabelingPipelineResponse\"6\x82\xd3\xe4\x93\x02\x30\"+/v1/labelpipelines/{namespace}/{name}:pause:\x01*\x12\x88\x02\n\x16ResumeLabelingPipeline\x12Y.github.com.metaprov.modelaapi.services.labelingpipeline.v1.ResumeLabelingPipelineRequest\x1aZ.github.com.metaprov.modelaapi.services.labelingpipeline.v1.ResumeLabelingPipelineResponse\"7\x82\xd3\xe4\x93\x02\x31\",/v1/labelpipelines/{namespace}/{name}:resume:\x01*B<Z:github.com/metaprov/modelaapi/services/labelingpipeline/v1b\x06proto3')



_LISTLABELINGPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['ListLabelingPipelineRequest']
_LISTLABELINGPIPELINEREQUEST_LABELSENTRY = _LISTLABELINGPIPELINEREQUEST.nested_types_by_name['LabelsEntry']
_LISTLABELINGPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['ListLabelingPipelineResponse']
_CREATELABELINGPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['CreateLabelingPipelineRequest']
_CREATELABELINGPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['CreateLabelingPipelineResponse']
_UPDATELABELINGPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['UpdateLabelingPipelineRequest']
_UPDATELABELINGPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['UpdateLabelingPipelineResponse']
_GETLABELINGPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['GetLabelingPipelineRequest']
_GETLABELINGPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['GetLabelingPipelineResponse']
_DELETELABELINGPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['DeleteLabelingPipelineRequest']
_DELETELABELINGPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['DeleteLabelingPipelineResponse']
_PAUSELABELINGPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['PauseLabelingPipelineResponse']
_PAUSELABELINGPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['PauseLabelingPipelineRequest']
_RESUMELABELINGPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['ResumeLabelingPipelineResponse']
_RESUMELABELINGPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['ResumeLabelingPipelineRequest']
ListLabelingPipelineRequest = _reflection.GeneratedProtocolMessageType('ListLabelingPipelineRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTLABELINGPIPELINEREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipeline.v1.labelingpipeline_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipeline.v1.ListLabelingPipelineRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTLABELINGPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipeline.v1.labelingpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipeline.v1.ListLabelingPipelineRequest)
  })
_sym_db.RegisterMessage(ListLabelingPipelineRequest)
_sym_db.RegisterMessage(ListLabelingPipelineRequest.LabelsEntry)

ListLabelingPipelineResponse = _reflection.GeneratedProtocolMessageType('ListLabelingPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTLABELINGPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipeline.v1.labelingpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipeline.v1.ListLabelingPipelineResponse)
  })
_sym_db.RegisterMessage(ListLabelingPipelineResponse)

CreateLabelingPipelineRequest = _reflection.GeneratedProtocolMessageType('CreateLabelingPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATELABELINGPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipeline.v1.labelingpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipeline.v1.CreateLabelingPipelineRequest)
  })
_sym_db.RegisterMessage(CreateLabelingPipelineRequest)

CreateLabelingPipelineResponse = _reflection.GeneratedProtocolMessageType('CreateLabelingPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATELABELINGPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipeline.v1.labelingpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipeline.v1.CreateLabelingPipelineResponse)
  })
_sym_db.RegisterMessage(CreateLabelingPipelineResponse)

UpdateLabelingPipelineRequest = _reflection.GeneratedProtocolMessageType('UpdateLabelingPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATELABELINGPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipeline.v1.labelingpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipeline.v1.UpdateLabelingPipelineRequest)
  })
_sym_db.RegisterMessage(UpdateLabelingPipelineRequest)

UpdateLabelingPipelineResponse = _reflection.GeneratedProtocolMessageType('UpdateLabelingPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATELABELINGPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipeline.v1.labelingpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipeline.v1.UpdateLabelingPipelineResponse)
  })
_sym_db.RegisterMessage(UpdateLabelingPipelineResponse)

GetLabelingPipelineRequest = _reflection.GeneratedProtocolMessageType('GetLabelingPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLABELINGPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipeline.v1.labelingpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipeline.v1.GetLabelingPipelineRequest)
  })
_sym_db.RegisterMessage(GetLabelingPipelineRequest)

GetLabelingPipelineResponse = _reflection.GeneratedProtocolMessageType('GetLabelingPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETLABELINGPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipeline.v1.labelingpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipeline.v1.GetLabelingPipelineResponse)
  })
_sym_db.RegisterMessage(GetLabelingPipelineResponse)

DeleteLabelingPipelineRequest = _reflection.GeneratedProtocolMessageType('DeleteLabelingPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETELABELINGPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipeline.v1.labelingpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipeline.v1.DeleteLabelingPipelineRequest)
  })
_sym_db.RegisterMessage(DeleteLabelingPipelineRequest)

DeleteLabelingPipelineResponse = _reflection.GeneratedProtocolMessageType('DeleteLabelingPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETELABELINGPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipeline.v1.labelingpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipeline.v1.DeleteLabelingPipelineResponse)
  })
_sym_db.RegisterMessage(DeleteLabelingPipelineResponse)

PauseLabelingPipelineResponse = _reflection.GeneratedProtocolMessageType('PauseLabelingPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _PAUSELABELINGPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipeline.v1.labelingpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipeline.v1.PauseLabelingPipelineResponse)
  })
_sym_db.RegisterMessage(PauseLabelingPipelineResponse)

PauseLabelingPipelineRequest = _reflection.GeneratedProtocolMessageType('PauseLabelingPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _PAUSELABELINGPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipeline.v1.labelingpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipeline.v1.PauseLabelingPipelineRequest)
  })
_sym_db.RegisterMessage(PauseLabelingPipelineRequest)

ResumeLabelingPipelineResponse = _reflection.GeneratedProtocolMessageType('ResumeLabelingPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESUMELABELINGPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipeline.v1.labelingpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipeline.v1.ResumeLabelingPipelineResponse)
  })
_sym_db.RegisterMessage(ResumeLabelingPipelineResponse)

ResumeLabelingPipelineRequest = _reflection.GeneratedProtocolMessageType('ResumeLabelingPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESUMELABELINGPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipeline.v1.labelingpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipeline.v1.ResumeLabelingPipelineRequest)
  })
_sym_db.RegisterMessage(ResumeLabelingPipelineRequest)

_LABELINGPIPELINESERVICE = DESCRIPTOR.services_by_name['LabelingPipelineService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z:github.com/metaprov/modelaapi/services/labelingpipeline/v1'
  _LISTLABELINGPIPELINEREQUEST_LABELSENTRY._options = None
  _LISTLABELINGPIPELINEREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _LABELINGPIPELINESERVICE.methods_by_name['ListLabelingPipelines']._options = None
  _LABELINGPIPELINESERVICE.methods_by_name['ListLabelingPipelines']._serialized_options = b'\202\323\344\223\002 \022\036/v1/labelpipelines/{namespace}'
  _LABELINGPIPELINESERVICE.methods_by_name['CreateLabelingPipeline']._options = None
  _LABELINGPIPELINESERVICE.methods_by_name['CreateLabelingPipeline']._serialized_options = b'\202\323\344\223\002\027\"\022/v1/labelpipelines:\001*'
  _LABELINGPIPELINESERVICE.methods_by_name['GetLabelingPipeline']._options = None
  _LABELINGPIPELINESERVICE.methods_by_name['GetLabelingPipeline']._serialized_options = b'\202\323\344\223\002\'\022%/v1/labelpipelines/{namespace}/{name}'
  _LABELINGPIPELINESERVICE.methods_by_name['UpdateLabelingPipeline']._options = None
  _LABELINGPIPELINESERVICE.methods_by_name['UpdateLabelingPipeline']._serialized_options = b'\202\323\344\223\002^\032Y/v1/labelpipelines/{labelingpipeline.metadata.namespace}/{labelingpipeline.metadata.name}:\001*'
  _LABELINGPIPELINESERVICE.methods_by_name['DeleteLabelingPipeline']._options = None
  _LABELINGPIPELINESERVICE.methods_by_name['DeleteLabelingPipeline']._serialized_options = b'\202\323\344\223\002**(/v1/labelingpipelines/{namespace}/{name}'
  _LABELINGPIPELINESERVICE.methods_by_name['PauseLabelingPipeline']._options = None
  _LABELINGPIPELINESERVICE.methods_by_name['PauseLabelingPipeline']._serialized_options = b'\202\323\344\223\0020\"+/v1/labelpipelines/{namespace}/{name}:pause:\001*'
  _LABELINGPIPELINESERVICE.methods_by_name['ResumeLabelingPipeline']._options = None
  _LABELINGPIPELINESERVICE.methods_by_name['ResumeLabelingPipeline']._serialized_options = b'\202\323\344\223\0021\",/v1/labelpipelines/{namespace}/{name}:resume:\001*'
  _LISTLABELINGPIPELINEREQUEST._serialized_start=280
  _LISTLABELINGPIPELINEREQUEST._serialized_end=549
  _LISTLABELINGPIPELINEREQUEST_LABELSENTRY._serialized_start=504
  _LISTLABELINGPIPELINEREQUEST_LABELSENTRY._serialized_end=549
  _LISTLABELINGPIPELINERESPONSE._serialized_start=552
  _LISTLABELINGPIPELINERESPONSE._serialized_end=710
  _CREATELABELINGPIPELINEREQUEST._serialized_start=713
  _CREATELABELINGPIPELINEREQUEST._serialized_end=842
  _CREATELABELINGPIPELINERESPONSE._serialized_start=844
  _CREATELABELINGPIPELINERESPONSE._serialized_end=876
  _UPDATELABELINGPIPELINEREQUEST._serialized_start=879
  _UPDATELABELINGPIPELINEREQUEST._serialized_end=1056
  _UPDATELABELINGPIPELINERESPONSE._serialized_start=1058
  _UPDATELABELINGPIPELINERESPONSE._serialized_end=1090
  _GETLABELINGPIPELINEREQUEST._serialized_start=1092
  _GETLABELINGPIPELINEREQUEST._serialized_end=1153
  _GETLABELINGPIPELINERESPONSE._serialized_start=1156
  _GETLABELINGPIPELINERESPONSE._serialized_end=1297
  _DELETELABELINGPIPELINEREQUEST._serialized_start=1299
  _DELETELABELINGPIPELINEREQUEST._serialized_end=1363
  _DELETELABELINGPIPELINERESPONSE._serialized_start=1365
  _DELETELABELINGPIPELINERESPONSE._serialized_end=1397
  _PAUSELABELINGPIPELINERESPONSE._serialized_start=1399
  _PAUSELABELINGPIPELINERESPONSE._serialized_end=1430
  _PAUSELABELINGPIPELINEREQUEST._serialized_start=1432
  _PAUSELABELINGPIPELINEREQUEST._serialized_end=1495
  _RESUMELABELINGPIPELINERESPONSE._serialized_start=1497
  _RESUMELABELINGPIPELINERESPONSE._serialized_end=1529
  _RESUMELABELINGPIPELINEREQUEST._serialized_start=1531
  _RESUMELABELINGPIPELINEREQUEST._serialized_end=1595
  _LABELINGPIPELINESERVICE._serialized_start=1598
  _LABELINGPIPELINESERVICE._serialized_end=3459
# @@protoc_insertion_point(module_scope)
