# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/modelpipeline/v1/modelpipeline.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKgithub.com/metaprov/modelaapi/services/modelpipeline/v1/modelpipeline.proto\x12\x37github.com.metaprov.modelaapi.services.modelpipeline.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1aHgithub.com/metaprov/modelaapi/pkg/apis/training/v1alpha1/generated.proto\"\x86\x02\n\x19ListModelPipelinesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12n\n\x06labels\x18\x02 \x03(\x0b\x32^.github.com.metaprov.modelaapi.services.modelpipeline.v1.ListModelPipelinesRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9a\x01\n\x1aListModelPipelinesResponse\x12\x63\n\x0emodelpipelines\x18\x01 \x01(\x0b\x32K.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x17\n\x15ModelPipelineResponse\"|\n\x1a\x43reateModelPipelineRequest\x12^\n\rmodelpipeline\x18\x01 \x01(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipeline\"\x1d\n\x1b\x43reateModelPipelineResponse\"\xac\x01\n\x1aUpdateModelPipelineRequest\x12^\n\rmodelpipeline\x18\x01 \x01(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipeline\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x1d\n\x1bUpdateModelPipelineResponse\":\n\x17GetModelPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x88\x01\n\x18GetModelPipelineResponse\x12^\n\rmodelpipeline\x18\x01 \x01(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipeline\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"=\n\x1a\x44\x65leteModelPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1d\n\x1b\x44\x65leteModelPipelineResponse\"y\n\x17RunModelPipelineRequest\x12^\n\rmodelpipeline\x18\x01 \x01(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipeline\"\x1a\n\x18RunModelPipelineResponse\"\x1c\n\x1aPauseModelPipelineResponse\"<\n\x19PauseModelPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1d\n\x1bResumeModelPipelineResponse\"=\n\x1aResumeModelPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t2\xb8\x0f\n\x14ModelPipelineService\x12\xe3\x01\n\x12ListModelPipelines\x12R.github.com.metaprov.modelaapi.services.modelpipeline.v1.ListModelPipelinesRequest\x1aS.github.com.metaprov.modelaapi.services.modelpipeline.v1.ListModelPipelinesResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/api/v1alpha1/modelpipelines\x12\xe9\x01\n\x13\x43reateModelPipeline\x12S.github.com.metaprov.modelaapi.services.modelpipeline.v1.CreateModelPipelineRequest\x1aT.github.com.metaprov.modelaapi.services.modelpipeline.v1.CreateModelPipelineResponse\"\'\x82\xd3\xe4\x93\x02!\"\x1c/api/v1alpha1/modelpipelines:\x01*\x12\xe4\x01\n\x10GetModelPipeline\x12P.github.com.metaprov.modelaapi.services.modelpipeline.v1.GetModelPipelineRequest\x1aQ.github.com.metaprov.modelaapi.services.modelpipeline.v1.GetModelPipelineResponse\"+\x82\xd3\xe4\x93\x02%\x12#/api/v1alpha1/modelpipelines/{name}\x12\x87\x02\n\x13UpdateModelPipeline\x12S.github.com.metaprov.modelaapi.services.modelpipeline.v1.UpdateModelPipelineRequest\x1aT.github.com.metaprov.modelaapi.services.modelpipeline.v1.UpdateModelPipelineResponse\"E\x82\xd3\xe4\x93\x02?\x1a:/api/v1alpha1/modelpipelines/{modelpipeline.metadata.name}:\x01*\x12\xe7\x01\n\x13\x44\x65leteModelPipeline\x12S.github.com.metaprov.modelaapi.services.modelpipeline.v1.DeleteModelPipelineRequest\x1aT.github.com.metaprov.modelaapi.services.modelpipeline.v1.DeleteModelPipelineResponse\"%\x82\xd3\xe4\x93\x02\x1f*\x1d/api/v1/modelpipelines/{name}\x12\x9c\x02\n\x10RunModelPipeline\x12P.github.com.metaprov.modelaapi.services.modelpipeline.v1.RunModelPipelineRequest\x1aQ.github.com.metaprov.modelaapi.services.modelpipeline.v1.RunModelPipelineResponse\"c\x82\xd3\xe4\x93\x02]\"[/api/v1/modelpipelines/{modelpipeline.metadata.namespace}/{modelpipeline.metadata.name}:run\x12\xe6\x01\n\x12PauseModelPipeline\x12R.github.com.metaprov.modelaapi.services.modelpipeline.v1.PauseModelPipelineRequest\x1aS.github.com.metaprov.modelaapi.services.modelpipeline.v1.PauseModelPipelineResponse\"\'\x82\xd3\xe4\x93\x02!\"\x1f/v1/modelpipelines/{name}:pause\x12\xea\x01\n\x13ResumeModelPipeline\x12S.github.com.metaprov.modelaapi.services.modelpipeline.v1.ResumeModelPipelineRequest\x1aT.github.com.metaprov.modelaapi.services.modelpipeline.v1.ResumeModelPipelineResponse\"(\x82\xd3\xe4\x93\x02\"\" /v1/modelpipelines/{name}:resumeB9Z7github.com/metaprov/modelaapi/services/modelpipeline/v1b\x06proto3')



_LISTMODELPIPELINESREQUEST = DESCRIPTOR.message_types_by_name['ListModelPipelinesRequest']
_LISTMODELPIPELINESREQUEST_LABELSENTRY = _LISTMODELPIPELINESREQUEST.nested_types_by_name['LabelsEntry']
_LISTMODELPIPELINESRESPONSE = DESCRIPTOR.message_types_by_name['ListModelPipelinesResponse']
_MODELPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['ModelPipelineResponse']
_CREATEMODELPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['CreateModelPipelineRequest']
_CREATEMODELPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['CreateModelPipelineResponse']
_UPDATEMODELPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['UpdateModelPipelineRequest']
_UPDATEMODELPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['UpdateModelPipelineResponse']
_GETMODELPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['GetModelPipelineRequest']
_GETMODELPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['GetModelPipelineResponse']
_DELETEMODELPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['DeleteModelPipelineRequest']
_DELETEMODELPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['DeleteModelPipelineResponse']
_RUNMODELPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['RunModelPipelineRequest']
_RUNMODELPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['RunModelPipelineResponse']
_PAUSEMODELPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['PauseModelPipelineResponse']
_PAUSEMODELPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['PauseModelPipelineRequest']
_RESUMEMODELPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['ResumeModelPipelineResponse']
_RESUMEMODELPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['ResumeModelPipelineRequest']
ListModelPipelinesRequest = _reflection.GeneratedProtocolMessageType('ListModelPipelinesRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTMODELPIPELINESREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.ListModelPipelinesRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTMODELPIPELINESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.ListModelPipelinesRequest)
  })
_sym_db.RegisterMessage(ListModelPipelinesRequest)
_sym_db.RegisterMessage(ListModelPipelinesRequest.LabelsEntry)

ListModelPipelinesResponse = _reflection.GeneratedProtocolMessageType('ListModelPipelinesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELPIPELINESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.ListModelPipelinesResponse)
  })
_sym_db.RegisterMessage(ListModelPipelinesResponse)

ModelPipelineResponse = _reflection.GeneratedProtocolMessageType('ModelPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _MODELPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.ModelPipelineResponse)
  })
_sym_db.RegisterMessage(ModelPipelineResponse)

CreateModelPipelineRequest = _reflection.GeneratedProtocolMessageType('CreateModelPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.CreateModelPipelineRequest)
  })
_sym_db.RegisterMessage(CreateModelPipelineRequest)

CreateModelPipelineResponse = _reflection.GeneratedProtocolMessageType('CreateModelPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.CreateModelPipelineResponse)
  })
_sym_db.RegisterMessage(CreateModelPipelineResponse)

UpdateModelPipelineRequest = _reflection.GeneratedProtocolMessageType('UpdateModelPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.UpdateModelPipelineRequest)
  })
_sym_db.RegisterMessage(UpdateModelPipelineRequest)

UpdateModelPipelineResponse = _reflection.GeneratedProtocolMessageType('UpdateModelPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.UpdateModelPipelineResponse)
  })
_sym_db.RegisterMessage(UpdateModelPipelineResponse)

GetModelPipelineRequest = _reflection.GeneratedProtocolMessageType('GetModelPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.GetModelPipelineRequest)
  })
_sym_db.RegisterMessage(GetModelPipelineRequest)

GetModelPipelineResponse = _reflection.GeneratedProtocolMessageType('GetModelPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.GetModelPipelineResponse)
  })
_sym_db.RegisterMessage(GetModelPipelineResponse)

DeleteModelPipelineRequest = _reflection.GeneratedProtocolMessageType('DeleteModelPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.DeleteModelPipelineRequest)
  })
_sym_db.RegisterMessage(DeleteModelPipelineRequest)

DeleteModelPipelineResponse = _reflection.GeneratedProtocolMessageType('DeleteModelPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.DeleteModelPipelineResponse)
  })
_sym_db.RegisterMessage(DeleteModelPipelineResponse)

RunModelPipelineRequest = _reflection.GeneratedProtocolMessageType('RunModelPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _RUNMODELPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.RunModelPipelineRequest)
  })
_sym_db.RegisterMessage(RunModelPipelineRequest)

RunModelPipelineResponse = _reflection.GeneratedProtocolMessageType('RunModelPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _RUNMODELPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.RunModelPipelineResponse)
  })
_sym_db.RegisterMessage(RunModelPipelineResponse)

PauseModelPipelineResponse = _reflection.GeneratedProtocolMessageType('PauseModelPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEMODELPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.PauseModelPipelineResponse)
  })
_sym_db.RegisterMessage(PauseModelPipelineResponse)

PauseModelPipelineRequest = _reflection.GeneratedProtocolMessageType('PauseModelPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEMODELPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.PauseModelPipelineRequest)
  })
_sym_db.RegisterMessage(PauseModelPipelineRequest)

ResumeModelPipelineResponse = _reflection.GeneratedProtocolMessageType('ResumeModelPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEMODELPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.ResumeModelPipelineResponse)
  })
_sym_db.RegisterMessage(ResumeModelPipelineResponse)

ResumeModelPipelineRequest = _reflection.GeneratedProtocolMessageType('ResumeModelPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEMODELPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.ResumeModelPipelineRequest)
  })
_sym_db.RegisterMessage(ResumeModelPipelineRequest)

_MODELPIPELINESERVICE = DESCRIPTOR.services_by_name['ModelPipelineService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z7github.com/metaprov/modelaapi/services/modelpipeline/v1'
  _LISTMODELPIPELINESREQUEST_LABELSENTRY._options = None
  _LISTMODELPIPELINESREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _MODELPIPELINESERVICE.methods_by_name['ListModelPipelines']._options = None
  _MODELPIPELINESERVICE.methods_by_name['ListModelPipelines']._serialized_options = b'\202\323\344\223\002\036\022\034/api/v1alpha1/modelpipelines'
  _MODELPIPELINESERVICE.methods_by_name['CreateModelPipeline']._options = None
  _MODELPIPELINESERVICE.methods_by_name['CreateModelPipeline']._serialized_options = b'\202\323\344\223\002!\"\034/api/v1alpha1/modelpipelines:\001*'
  _MODELPIPELINESERVICE.methods_by_name['GetModelPipeline']._options = None
  _MODELPIPELINESERVICE.methods_by_name['GetModelPipeline']._serialized_options = b'\202\323\344\223\002%\022#/api/v1alpha1/modelpipelines/{name}'
  _MODELPIPELINESERVICE.methods_by_name['UpdateModelPipeline']._options = None
  _MODELPIPELINESERVICE.methods_by_name['UpdateModelPipeline']._serialized_options = b'\202\323\344\223\002?\032:/api/v1alpha1/modelpipelines/{modelpipeline.metadata.name}:\001*'
  _MODELPIPELINESERVICE.methods_by_name['DeleteModelPipeline']._options = None
  _MODELPIPELINESERVICE.methods_by_name['DeleteModelPipeline']._serialized_options = b'\202\323\344\223\002\037*\035/api/v1/modelpipelines/{name}'
  _MODELPIPELINESERVICE.methods_by_name['RunModelPipeline']._options = None
  _MODELPIPELINESERVICE.methods_by_name['RunModelPipeline']._serialized_options = b'\202\323\344\223\002]\"[/api/v1/modelpipelines/{modelpipeline.metadata.namespace}/{modelpipeline.metadata.name}:run'
  _MODELPIPELINESERVICE.methods_by_name['PauseModelPipeline']._options = None
  _MODELPIPELINESERVICE.methods_by_name['PauseModelPipeline']._serialized_options = b'\202\323\344\223\002!\"\037/v1/modelpipelines/{name}:pause'
  _MODELPIPELINESERVICE.methods_by_name['ResumeModelPipeline']._options = None
  _MODELPIPELINESERVICE.methods_by_name['ResumeModelPipeline']._serialized_options = b'\202\323\344\223\002\"\" /v1/modelpipelines/{name}:resume'
  _LISTMODELPIPELINESREQUEST._serialized_start=275
  _LISTMODELPIPELINESREQUEST._serialized_end=537
  _LISTMODELPIPELINESREQUEST_LABELSENTRY._serialized_start=492
  _LISTMODELPIPELINESREQUEST_LABELSENTRY._serialized_end=537
  _LISTMODELPIPELINESRESPONSE._serialized_start=540
  _LISTMODELPIPELINESRESPONSE._serialized_end=694
  _MODELPIPELINERESPONSE._serialized_start=696
  _MODELPIPELINERESPONSE._serialized_end=719
  _CREATEMODELPIPELINEREQUEST._serialized_start=721
  _CREATEMODELPIPELINEREQUEST._serialized_end=845
  _CREATEMODELPIPELINERESPONSE._serialized_start=847
  _CREATEMODELPIPELINERESPONSE._serialized_end=876
  _UPDATEMODELPIPELINEREQUEST._serialized_start=879
  _UPDATEMODELPIPELINEREQUEST._serialized_end=1051
  _UPDATEMODELPIPELINERESPONSE._serialized_start=1053
  _UPDATEMODELPIPELINERESPONSE._serialized_end=1082
  _GETMODELPIPELINEREQUEST._serialized_start=1084
  _GETMODELPIPELINEREQUEST._serialized_end=1142
  _GETMODELPIPELINERESPONSE._serialized_start=1145
  _GETMODELPIPELINERESPONSE._serialized_end=1281
  _DELETEMODELPIPELINEREQUEST._serialized_start=1283
  _DELETEMODELPIPELINEREQUEST._serialized_end=1344
  _DELETEMODELPIPELINERESPONSE._serialized_start=1346
  _DELETEMODELPIPELINERESPONSE._serialized_end=1375
  _RUNMODELPIPELINEREQUEST._serialized_start=1377
  _RUNMODELPIPELINEREQUEST._serialized_end=1498
  _RUNMODELPIPELINERESPONSE._serialized_start=1500
  _RUNMODELPIPELINERESPONSE._serialized_end=1526
  _PAUSEMODELPIPELINERESPONSE._serialized_start=1528
  _PAUSEMODELPIPELINERESPONSE._serialized_end=1556
  _PAUSEMODELPIPELINEREQUEST._serialized_start=1558
  _PAUSEMODELPIPELINEREQUEST._serialized_end=1618
  _RESUMEMODELPIPELINERESPONSE._serialized_start=1620
  _RESUMEMODELPIPELINERESPONSE._serialized_end=1649
  _RESUMEMODELPIPELINEREQUEST._serialized_start=1651
  _RESUMEMODELPIPELINEREQUEST._serialized_end=1712
  _MODELPIPELINESERVICE._serialized_start=1715
  _MODELPIPELINESERVICE._serialized_end=3691
# @@protoc_insertion_point(module_scope)
