# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/dataapp/v1/dataapp.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?github.com/metaprov/modelaapi/services/dataapp/v1/dataapp.proto\x12\x31github.com.metaprov.modelaapi.services.dataapp.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1aIgithub.com/metaprov/modelaapi/pkg/apis/inference/v1alpha1/generated.proto\"\xf4\x01\n\x13ListDataAppsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x62\n\x06labels\x18\x02 \x03(\x0b\x32R.github.com.metaprov.modelaapi.services.dataapp.v1.ListDataAppsRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x89\x01\n\x14ListDataAppsResponse\x12X\n\x08\x64\x61taapps\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.DataAppList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x17\n\x15\x43reateDataAppResponse\"k\n\x14\x43reateDataAppRequest\x12S\n\x07\x64\x61taapp\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.DataApp\"\x9b\x01\n\x14UpdateDataAppRequest\x12S\n\x07\x64\x61taapp\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.DataApp\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x17\n\x15UpdateDataAppResponse\"4\n\x11GetDataAppRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"w\n\x12GetDataAppResponse\x12S\n\x07\x64\x61taapp\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.DataApp\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"7\n\x14\x44\x65leteDataAppRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x17\n\x15\x44\x65leteDataAppResponse\"6\n\x13PauseDataAppRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x16\n\x14PauseDataAppResponse\"7\n\x14ResumeDataAppRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x17\n\x15ResumeDataAppResponse\"h\n\x11RunDataAppRequest\x12S\n\x07\x64\x61taapp\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.DataApp\"\x14\n\x12RunDataAppResponse2\xa9\r\n\x0e\x44\x61taAppService\x12\xc1\x01\n\x0cListDataApps\x12\x46.github.com.metaprov.modelaapi.services.dataapp.v1.ListDataAppsRequest\x1aG.github.com.metaprov.modelaapi.services.dataapp.v1.ListDataAppsResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/v1/dataapps/{namespace}\x12\xbb\x01\n\rCreateDataApp\x12G.github.com.metaprov.modelaapi.services.dataapp.v1.CreateDataAppRequest\x1aH.github.com.metaprov.modelaapi.services.dataapp.v1.CreateDataAppResponse\"\x17\x82\xd3\xe4\x93\x02\x11\"\x0c/v1/dataapps:\x01*\x12\xc2\x01\n\nGetDataApp\x12\x44.github.com.metaprov.modelaapi.services.dataapp.v1.GetDataAppRequest\x1a\x45.github.com.metaprov.modelaapi.services.dataapp.v1.GetDataAppResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/v1/dataapps/{namespace}/{name}\x12\xf0\x01\n\rUpdateDataApp\x12G.github.com.metaprov.modelaapi.services.dataapp.v1.UpdateDataAppRequest\x1aH.github.com.metaprov.modelaapi.services.dataapp.v1.UpdateDataAppResponse\"L\x82\xd3\xe4\x93\x02\x46\x1a\x41/v1/dataapps/{dataapp.metadata.namespace}/{dataapp.metadata.name}:\x01*\x12\xcb\x01\n\rDeleteDataApp\x12G.github.com.metaprov.modelaapi.services.dataapp.v1.DeleteDataAppRequest\x1aH.github.com.metaprov.modelaapi.services.dataapp.v1.DeleteDataAppResponse\"\'\x82\xd3\xe4\x93\x02!*\x1f/v1/dataapps/{namespace}/{name}\x12\xce\x01\n\x0cPauseDataApp\x12\x46.github.com.metaprov.modelaapi.services.dataapp.v1.PauseDataAppRequest\x1aG.github.com.metaprov.modelaapi.services.dataapp.v1.PauseDataAppResponse\"-\x82\xd3\xe4\x93\x02\'\"%/v1/dataapps/{namespace}/{name}:pause\x12\xe8\x01\n\nRunDataApp\x12\x44.github.com.metaprov.modelaapi.services.dataapp.v1.RunDataAppRequest\x1a\x45.github.com.metaprov.modelaapi.services.dataapp.v1.RunDataAppResponse\"M\x82\xd3\xe4\x93\x02G\"E/v1/dataapps/{dataapp.metadata.namespace}/{dataapp.metadata.name}:run\x12\xd2\x01\n\rResumeDataApp\x12G.github.com.metaprov.modelaapi.services.dataapp.v1.ResumeDataAppRequest\x1aH.github.com.metaprov.modelaapi.services.dataapp.v1.ResumeDataAppResponse\".\x82\xd3\xe4\x93\x02(\"&/v1/dataapps/{namespace}/{name}:resumeB3Z1github.com/metaprov/modelaapi/services/dataapp/v1b\x06proto3')



_LISTDATAAPPSREQUEST = DESCRIPTOR.message_types_by_name['ListDataAppsRequest']
_LISTDATAAPPSREQUEST_LABELSENTRY = _LISTDATAAPPSREQUEST.nested_types_by_name['LabelsEntry']
_LISTDATAAPPSRESPONSE = DESCRIPTOR.message_types_by_name['ListDataAppsResponse']
_CREATEDATAAPPRESPONSE = DESCRIPTOR.message_types_by_name['CreateDataAppResponse']
_CREATEDATAAPPREQUEST = DESCRIPTOR.message_types_by_name['CreateDataAppRequest']
_UPDATEDATAAPPREQUEST = DESCRIPTOR.message_types_by_name['UpdateDataAppRequest']
_UPDATEDATAAPPRESPONSE = DESCRIPTOR.message_types_by_name['UpdateDataAppResponse']
_GETDATAAPPREQUEST = DESCRIPTOR.message_types_by_name['GetDataAppRequest']
_GETDATAAPPRESPONSE = DESCRIPTOR.message_types_by_name['GetDataAppResponse']
_DELETEDATAAPPREQUEST = DESCRIPTOR.message_types_by_name['DeleteDataAppRequest']
_DELETEDATAAPPRESPONSE = DESCRIPTOR.message_types_by_name['DeleteDataAppResponse']
_PAUSEDATAAPPREQUEST = DESCRIPTOR.message_types_by_name['PauseDataAppRequest']
_PAUSEDATAAPPRESPONSE = DESCRIPTOR.message_types_by_name['PauseDataAppResponse']
_RESUMEDATAAPPREQUEST = DESCRIPTOR.message_types_by_name['ResumeDataAppRequest']
_RESUMEDATAAPPRESPONSE = DESCRIPTOR.message_types_by_name['ResumeDataAppResponse']
_RUNDATAAPPREQUEST = DESCRIPTOR.message_types_by_name['RunDataAppRequest']
_RUNDATAAPPRESPONSE = DESCRIPTOR.message_types_by_name['RunDataAppResponse']
ListDataAppsRequest = _reflection.GeneratedProtocolMessageType('ListDataAppsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTDATAAPPSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.ListDataAppsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTDATAAPPSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.ListDataAppsRequest)
  })
_sym_db.RegisterMessage(ListDataAppsRequest)
_sym_db.RegisterMessage(ListDataAppsRequest.LabelsEntry)

ListDataAppsResponse = _reflection.GeneratedProtocolMessageType('ListDataAppsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATAAPPSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.ListDataAppsResponse)
  })
_sym_db.RegisterMessage(ListDataAppsResponse)

CreateDataAppResponse = _reflection.GeneratedProtocolMessageType('CreateDataAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAAPPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.CreateDataAppResponse)
  })
_sym_db.RegisterMessage(CreateDataAppResponse)

CreateDataAppRequest = _reflection.GeneratedProtocolMessageType('CreateDataAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.CreateDataAppRequest)
  })
_sym_db.RegisterMessage(CreateDataAppRequest)

UpdateDataAppRequest = _reflection.GeneratedProtocolMessageType('UpdateDataAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.UpdateDataAppRequest)
  })
_sym_db.RegisterMessage(UpdateDataAppRequest)

UpdateDataAppResponse = _reflection.GeneratedProtocolMessageType('UpdateDataAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAAPPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.UpdateDataAppResponse)
  })
_sym_db.RegisterMessage(UpdateDataAppResponse)

GetDataAppRequest = _reflection.GeneratedProtocolMessageType('GetDataAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATAAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.GetDataAppRequest)
  })
_sym_db.RegisterMessage(GetDataAppRequest)

GetDataAppResponse = _reflection.GeneratedProtocolMessageType('GetDataAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDATAAPPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.GetDataAppResponse)
  })
_sym_db.RegisterMessage(GetDataAppResponse)

DeleteDataAppRequest = _reflection.GeneratedProtocolMessageType('DeleteDataAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATAAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.DeleteDataAppRequest)
  })
_sym_db.RegisterMessage(DeleteDataAppRequest)

DeleteDataAppResponse = _reflection.GeneratedProtocolMessageType('DeleteDataAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATAAPPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.DeleteDataAppResponse)
  })
_sym_db.RegisterMessage(DeleteDataAppResponse)

PauseDataAppRequest = _reflection.GeneratedProtocolMessageType('PauseDataAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEDATAAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.PauseDataAppRequest)
  })
_sym_db.RegisterMessage(PauseDataAppRequest)

PauseDataAppResponse = _reflection.GeneratedProtocolMessageType('PauseDataAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEDATAAPPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.PauseDataAppResponse)
  })
_sym_db.RegisterMessage(PauseDataAppResponse)

ResumeDataAppRequest = _reflection.GeneratedProtocolMessageType('ResumeDataAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEDATAAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.ResumeDataAppRequest)
  })
_sym_db.RegisterMessage(ResumeDataAppRequest)

ResumeDataAppResponse = _reflection.GeneratedProtocolMessageType('ResumeDataAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEDATAAPPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.ResumeDataAppResponse)
  })
_sym_db.RegisterMessage(ResumeDataAppResponse)

RunDataAppRequest = _reflection.GeneratedProtocolMessageType('RunDataAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _RUNDATAAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.RunDataAppRequest)
  })
_sym_db.RegisterMessage(RunDataAppRequest)

RunDataAppResponse = _reflection.GeneratedProtocolMessageType('RunDataAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _RUNDATAAPPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataapp.v1.dataapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataapp.v1.RunDataAppResponse)
  })
_sym_db.RegisterMessage(RunDataAppResponse)

_DATAAPPSERVICE = DESCRIPTOR.services_by_name['DataAppService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/metaprov/modelaapi/services/dataapp/v1'
  _LISTDATAAPPSREQUEST_LABELSENTRY._options = None
  _LISTDATAAPPSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _DATAAPPSERVICE.methods_by_name['ListDataApps']._options = None
  _DATAAPPSERVICE.methods_by_name['ListDataApps']._serialized_options = b'\202\323\344\223\002\032\022\030/v1/dataapps/{namespace}'
  _DATAAPPSERVICE.methods_by_name['CreateDataApp']._options = None
  _DATAAPPSERVICE.methods_by_name['CreateDataApp']._serialized_options = b'\202\323\344\223\002\021\"\014/v1/dataapps:\001*'
  _DATAAPPSERVICE.methods_by_name['GetDataApp']._options = None
  _DATAAPPSERVICE.methods_by_name['GetDataApp']._serialized_options = b'\202\323\344\223\002!\022\037/v1/dataapps/{namespace}/{name}'
  _DATAAPPSERVICE.methods_by_name['UpdateDataApp']._options = None
  _DATAAPPSERVICE.methods_by_name['UpdateDataApp']._serialized_options = b'\202\323\344\223\002F\032A/v1/dataapps/{dataapp.metadata.namespace}/{dataapp.metadata.name}:\001*'
  _DATAAPPSERVICE.methods_by_name['DeleteDataApp']._options = None
  _DATAAPPSERVICE.methods_by_name['DeleteDataApp']._serialized_options = b'\202\323\344\223\002!*\037/v1/dataapps/{namespace}/{name}'
  _DATAAPPSERVICE.methods_by_name['PauseDataApp']._options = None
  _DATAAPPSERVICE.methods_by_name['PauseDataApp']._serialized_options = b'\202\323\344\223\002\'\"%/v1/dataapps/{namespace}/{name}:pause'
  _DATAAPPSERVICE.methods_by_name['RunDataApp']._options = None
  _DATAAPPSERVICE.methods_by_name['RunDataApp']._serialized_options = b'\202\323\344\223\002G\"E/v1/dataapps/{dataapp.metadata.namespace}/{dataapp.metadata.name}:run'
  _DATAAPPSERVICE.methods_by_name['ResumeDataApp']._options = None
  _DATAAPPSERVICE.methods_by_name['ResumeDataApp']._serialized_options = b'\202\323\344\223\002(\"&/v1/dataapps/{namespace}/{name}:resume'
  _LISTDATAAPPSREQUEST._serialized_start=258
  _LISTDATAAPPSREQUEST._serialized_end=502
  _LISTDATAAPPSREQUEST_LABELSENTRY._serialized_start=457
  _LISTDATAAPPSREQUEST_LABELSENTRY._serialized_end=502
  _LISTDATAAPPSRESPONSE._serialized_start=505
  _LISTDATAAPPSRESPONSE._serialized_end=642
  _CREATEDATAAPPRESPONSE._serialized_start=644
  _CREATEDATAAPPRESPONSE._serialized_end=667
  _CREATEDATAAPPREQUEST._serialized_start=669
  _CREATEDATAAPPREQUEST._serialized_end=776
  _UPDATEDATAAPPREQUEST._serialized_start=779
  _UPDATEDATAAPPREQUEST._serialized_end=934
  _UPDATEDATAAPPRESPONSE._serialized_start=936
  _UPDATEDATAAPPRESPONSE._serialized_end=959
  _GETDATAAPPREQUEST._serialized_start=961
  _GETDATAAPPREQUEST._serialized_end=1013
  _GETDATAAPPRESPONSE._serialized_start=1015
  _GETDATAAPPRESPONSE._serialized_end=1134
  _DELETEDATAAPPREQUEST._serialized_start=1136
  _DELETEDATAAPPREQUEST._serialized_end=1191
  _DELETEDATAAPPRESPONSE._serialized_start=1193
  _DELETEDATAAPPRESPONSE._serialized_end=1216
  _PAUSEDATAAPPREQUEST._serialized_start=1218
  _PAUSEDATAAPPREQUEST._serialized_end=1272
  _PAUSEDATAAPPRESPONSE._serialized_start=1274
  _PAUSEDATAAPPRESPONSE._serialized_end=1296
  _RESUMEDATAAPPREQUEST._serialized_start=1298
  _RESUMEDATAAPPREQUEST._serialized_end=1353
  _RESUMEDATAAPPRESPONSE._serialized_start=1355
  _RESUMEDATAAPPRESPONSE._serialized_end=1378
  _RUNDATAAPPREQUEST._serialized_start=1380
  _RUNDATAAPPREQUEST._serialized_end=1484
  _RUNDATAAPPRESPONSE._serialized_start=1486
  _RUNDATAAPPRESPONSE._serialized_end=1506
  _DATAAPPSERVICE._serialized_start=1509
  _DATAAPPSERVICE._serialized_end=3214
# @@protoc_insertion_point(module_scope)
