# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.dataapp.v1 import dataapp_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2


class DataAppServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListDataApps = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService/ListDataApps',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.ListDataAppsRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.ListDataAppsResponse.FromString,
                )
        self.CreateDataApp = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService/CreateDataApp',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.CreateDataAppRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.CreateDataAppResponse.FromString,
                )
        self.GetDataApp = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService/GetDataApp',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.GetDataAppRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.GetDataAppResponse.FromString,
                )
        self.UpdateDataApp = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService/UpdateDataApp',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.UpdateDataAppRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.UpdateDataAppResponse.FromString,
                )
        self.DeleteDataApp = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService/DeleteDataApp',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.DeleteDataAppRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.DeleteDataAppResponse.FromString,
                )
        self.PauseDataApp = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService/PauseDataApp',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.PauseDataAppRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.PauseDataAppResponse.FromString,
                )
        self.RunDataApp = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService/RunDataApp',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.RunDataAppRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.RunDataAppResponse.FromString,
                )
        self.ResumeDataApp = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService/ResumeDataApp',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.ResumeDataAppRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.ResumeDataAppResponse.FromString,
                )


class DataAppServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListDataApps(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDataApp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDataApp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDataApp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDataApp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PauseDataApp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RunDataApp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResumeDataApp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DataAppServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListDataApps': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDataApps,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.ListDataAppsRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.ListDataAppsResponse.SerializeToString,
            ),
            'CreateDataApp': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDataApp,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.CreateDataAppRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.CreateDataAppResponse.SerializeToString,
            ),
            'GetDataApp': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDataApp,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.GetDataAppRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.GetDataAppResponse.SerializeToString,
            ),
            'UpdateDataApp': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDataApp,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.UpdateDataAppRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.UpdateDataAppResponse.SerializeToString,
            ),
            'DeleteDataApp': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDataApp,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.DeleteDataAppRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.DeleteDataAppResponse.SerializeToString,
            ),
            'PauseDataApp': grpc.unary_unary_rpc_method_handler(
                    servicer.PauseDataApp,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.PauseDataAppRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.PauseDataAppResponse.SerializeToString,
            ),
            'RunDataApp': grpc.unary_unary_rpc_method_handler(
                    servicer.RunDataApp,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.RunDataAppRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.RunDataAppResponse.SerializeToString,
            ),
            'ResumeDataApp': grpc.unary_unary_rpc_method_handler(
                    servicer.ResumeDataApp,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.ResumeDataAppRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.ResumeDataAppResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DataAppService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListDataApps(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService/ListDataApps',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.ListDataAppsRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.ListDataAppsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateDataApp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService/CreateDataApp',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.CreateDataAppRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.CreateDataAppResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDataApp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService/GetDataApp',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.GetDataAppRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.GetDataAppResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDataApp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService/UpdateDataApp',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.UpdateDataAppRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.UpdateDataAppResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteDataApp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService/DeleteDataApp',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.DeleteDataAppRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.DeleteDataAppResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PauseDataApp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService/PauseDataApp',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.PauseDataAppRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.PauseDataAppResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RunDataApp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService/RunDataApp',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.RunDataAppRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.RunDataAppResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResumeDataApp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.dataapp.v1.DataAppService/ResumeDataApp',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.ResumeDataAppRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataapp_dot_v1_dot_dataapp__pb2.ResumeDataAppResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
